==> realestate-supervise-common-1.1.0-20241231.014802-54-sources.jar: cn/gtmap/realestate/supervise/entity/BaNydsyqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 农用地使用权（非林地）属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_nydsyq_ls"
)
public class BaNydsyqLs implements Serializable {

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String zl;

    @XmlAttribute
    private String fbfdm;

    @XmlAttribute
    private String fbfmc;

    @XmlAttribute
    private float cbmj;

    @XmlAttribute
    private Date cbqssj;

    @XmlAttribute
    private Date cbjssj;

    @XmlAttribute
    private String tdsyqxz;

    @XmlAttribute
    @Nullable
    private String syttlx;

    @XmlAttribute
    @Nullable
    private String yzyfs;

    @XmlAttribute
    @Nullable
    private String cyzl;

    @XmlAttribute
    @Nullable
    private int syzcl;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String cbqx;

    @XmlAttribute
    private String cbhtbm;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String ydyhfl;

    @XmlAttribute
    private String tdcbht;

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getCbqx() {
        return cbqx;
    }

    public void setCbqx(String cbqx) {
        this.cbqx = cbqx;
    }

    public String getCbhtbm() {
        return cbhtbm;
    }

    public void setCbhtbm(String cbhtbm) {
        this.cbhtbm = cbhtbm;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdcbht() {
        return tdcbht;
    }

    public void setTdcbht(String tdcbht) {
        this.tdcbht = tdcbht;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getZl() {
        return zl;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public float getCbmj() {
        return cbmj;
    }

    public Date getCbqssj() {
        return cbqssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public int getSyzcl() {
        return syzcl;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public void setCbmj(float cbmj) {
        this.cbmj = cbmj;
    }

    public void setCbqssj(Date cbqssj) {
        this.cbqssj = cbqssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public void setSyzcl(int syzcl) {
        this.syzcl = syzcl;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaNydsyqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.sqlx;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 农用地使用权（非林地）属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_nydsyq_ls"
)
public class BaNydsyqLs implements Serializable {

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String zl;

    @XmlAttribute
    private String fbfdm;

    @XmlAttribute
    private String fbfmc;

    @XmlAttribute
    private float cbmj;

    @XmlAttribute
    private Date cbqssj;

    @XmlAttribute
    private Date cbjssj;

    @XmlAttribute
    private String tdsyqxz;

    @XmlAttribute
    @Nullable
    private String syttlx;

    @XmlAttribute
    @Nullable
    private String yzyfs;

    @XmlAttribute
    @Nullable
    private String cyzl;

    @XmlAttribute
    @Nullable
    private int syzcl;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String cbqx;

    @XmlAttribute
    private String cbhtbm;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String ydyhfl;

    @XmlAttribute
    private String tdcbht;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getCbqx() {
        return cbqx;
    }

    public void setCbqx(String cbqx) {
        this.cbqx = cbqx;
    }

    public String getCbhtbm() {
        return cbhtbm;
    }

    public void setCbhtbm(String cbhtbm) {
        this.cbhtbm = cbhtbm;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdcbht() {
        return tdcbht;
    }

    public void setTdcbht(String tdcbht) {
        this.tdcbht = tdcbht;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getZl() {
        return zl;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public float getCbmj() {
        return cbmj;
    }

    public Date getCbqssj() {
        return cbqssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public int getSyzcl() {
        return syzcl;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public void setCbmj(float cbmj) {
        this.cbmj = cbmj;
    }

    public void setCbqssj(Date cbqssj) {
        this.cbqssj = cbqssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public void setSyzcl(int syzcl) {
        this.syzcl = syzcl;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}
